Bootstrap

Struct Bootstrap 

pub struct Bootstrap {
    pub supervisor: Supervisor,
    pub guard: BootstrapGuard,
}
The result of running AppBootstrapper::bootstrap.

Bundles together the BootstrapGuard that must be held for the lifetime of the application with the Supervisor that drives the background workers spawned during bootstrap. Callers must arrange for the supervisor to be run (either directly or by adding it to a parent supervisor) for those workers to make progress.

Fields

supervisor: Supervisor

Supervisor populated with workers for all background async tasks created during bootstrap.

guard: BootstrapGuard

Drop guard for resources acquired during bootstrap.