pub struct Bootstrap {
pub supervisor: Supervisor,
pub guard: BootstrapGuard,
}Expand description
The result of running AppBootstrapper::bootstrap.
Bundles together the BootstrapGuard that must be held for the lifetime of the application with the
Supervisor that drives the background workers spawned during bootstrap. Callers must arrange for the
supervisor to be run (either directly or by adding it to a parent supervisor) for those workers to make
progress.
Fields
supervisor: SupervisorSupervisor populated with workers for all background async tasks created during bootstrap.
guard: BootstrapGuardDrop guard for resources acquired during bootstrap.